==> anycmd-jupyter-magic-0.0.1.tar.gz: anycmd-jupyter-magic-0.0.1/README.md <==
# AnyCmd

&nbsp;&nbsp;&nbsp;&nbsp;Do the provided cell magics not quite fit your needs? AnyCmd is a versatile Jupyter cell magic that allows you to run a cell with any command line utility. Simply specify the command you want to run as arguments after the magic. Access the contents of the cell as a file using the literal string "%FILE" or "%FILE.someExtension"  
&nbsp;&nbsp;&nbsp;&nbsp;By default, the command specified after the magic will be run from a temporary working directory. However, you may use -d/--dir <directory> to chdir into a custom directory before running the cell command. Use "-d ." to run it in the current working directory.  
&nbsp;&nbsp;&nbsp;&nbsp;Use -i/--inplace if you would like to write the cell contents temp files in the specified working directory, rather than the temporary directory (has no effect without --dir). This may help with compilers that reference libraries in the same directory, for instance.  
&nbsp;&nbsp;&nbsp;&nbsp;Use "-p/--print" to print command output live, instead of outputting to the cell. This may improve readability, and make it easier to debug long-running commands.  
&nbsp;&nbsp;&nbsp;&nbsp;-l/--lines adds a newline character before the cell contents in the temporary file to offset the first line taken up by the cell magic. This may help prevent interpreter error messages that reference a line number one line before the actual error when jupyter line numbers are enabled.

  
#### You may install this package via PyPi:
```python3 -m pip install anycmd-jupyter-magic```  

#### Example (compiling and running c++):  
___
```
%%any -p -- clang++ -O3 %FILE.cpp -o file && ./file

#include <iostream>  
using namespace std;  
int main(int argc, const char** argv) {  
  cout << "Hello World\n";  
}  
```
___
Result:  
Hello World

==> anycmd-jupyter-magic-0.1.0.tar.gz: anycmd-jupyter-magic-0.1.0/README.md <==
# AnyCmd

&nbsp;&nbsp;&nbsp;&nbsp;Do the provided cell magics not quite fit your needs? AnyCmd is a versatile Jupyter cell magic that allows you to run a cell with any command line utility. Simply specify the command you want to run as arguments after the magic. Access the contents of the cell as a file using the literal string "%FILE" or "%FILE.someExtension"  
&nbsp;&nbsp;&nbsp;&nbsp;By default, the command specified after the magic will be run from a temporary working directory. However, you may use -d/--dir <directory> to chdir into a custom directory before running the cell command. Use "-d ." to run it in the current working directory.  
&nbsp;&nbsp;&nbsp;&nbsp;Use -i/--inplace if you would like to write the cell contents temp files in the specified working directory, rather than the temporary directory (has no effect without --dir). This may help with compilers that reference libraries in the same directory, for instance.  
&nbsp;&nbsp;&nbsp;&nbsp;Use "-p/--print" to print command output live, instead of outputting to the cell. This may improve readability, and make it easier to debug long-running commands.  
&nbsp;&nbsp;&nbsp;&nbsp;-l/--lines adds a newline character before the cell contents in the temporary file to offset the first line taken up by the cell magic. This may help prevent interpreter error messages that reference a line number one line before the actual error when jupyter line numbers are enabled.

  
#### You may install this package via PyPi:
```
!pip install anycmd-jupyter-magic
%load_ext anycmd
```

#### Example (compiling and running c++):  
___
```%%any -p -- clang++ -O3 %FILE.cpp -o file && ./file

#include <iostream>  
using namespace std;  
int main(int argc, const char** argv) {  
  cout << "Hello World\n";  
}  
```
___
Result:  
Hello World
